==> scalts-0.4.0.tgz: package/src/Try.js <==
/* tslint:disable:no-use-before-declare */
"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var Optional_1 = require('./Optional');
var Either_1 = require('./Either');
function Try(f) {
    try {
        return Success(f());
    }
    catch (e) {
        return Failure(e);
    }
}
exports.Try = Try;
function Success(a) {
    return new SuccessImpl(a);
}
exports.Success = Success;
function Failure(e) {
    return new FailureImpl(e);
}
exports.Failure = Failure;
//------------------------------------
//
// Implementation section.
//
//------------------------------------
var TryImpl = (function () {
    function TryImpl() {
    }
    TryImpl.prototype.toString = function () {
        return this.isSuccess ? "Success(" + this.get() + "})" : "Failure(" + this.getError() + "})";
    };
    TryImpl.prototype.get = function () {
        throw 'impl child';
    };
    TryImpl.prototype.getError = function () {
        throw 'impl child';
    };
    TryImpl.prototype.flatMap = function (f) {
        throw 'impl child';
    };
    TryImpl.prototype.map = function (f) {
        throw 'impl child';
    };
    TryImpl.prototype.filter = function (f) {
        throw 'impl child';
    };
    TryImpl.prototype.toOptional = function () {
        return this.isSuccess ? Optional_1.Some(this.get()) : Optional_1.None;
    };
    TryImpl.prototype.toEither = function () {
        return this.isSuccess ? Either_1.Right(this.get()) : Either_1.Left(this.getError());
    };
    TryImpl.prototype.failed = function () {
        throw 'impl child';
    };
    TryImpl.prototype.recover = function (f) {
        throw 'impl child';
    };
    TryImpl.prototype.recoverWith = function (f) {
        throw 'impl child';
    };
    TryImpl.prototype.fold = function (fe, ff) {
        return this.isFailure ? fe(this.getError()) : ff(this.get());
    };
    TryImpl.prototype.getOrElse = function (a) {
        return this.isFailure ? a() : this.get();
    };
    TryImpl.prototype.orElse = function (a) {
        return this.isFailure ? a : this;
    };
    TryImpl.prototype.foreach = function (f) {
        if (this.isSuccess) {
            f(this.get());
        }
    };
    TryImpl.prototype.transform = function (fs, ff) {
        try {
            return this.isSuccess ? fs(this.get()) : ff(this.getError());
        }
        catch (e) {
            return Failure(e);
        }
    };
    /** @override */
    TryImpl.prototype.apply1 = function (ob, f) {
        return this.flatMap(function (a) { return ob.map(function (b) { return f(a, b); }); });
    };
    /** @override */
    TryImpl.prototype.apply2 = function (ob, oc, f) {
        return this.flatMap(function (a) { return ob.flatMap(function (b) { return oc.map(function (c) { return f(a, b, c); }); }); });
    };
    /** @override */
    TryImpl.prototype.apply3 = function (ob, oc, od, f) {
        return this.flatMap(function (a) { return ob.flatMap(function (b) { return oc.flatMap(function (c) { return od.map(function (d) { return f(a, b, c, d); }); }); }); });
    };
    /** @override */
    TryImpl.prototype.apply4 = function (ob, oc, od, oe, f) {
        return this.flatMap(function (a) { return ob.flatMap(function (b) { return oc.flatMap(function (c) { return od.flatMap(function (d) { return oe.map(function (e) { return f(a, b, c, d, e); }); }); }); }); });
    };
    /** @override */
    TryImpl.prototype.apply5 = function (ob, oc, od, oe, of, f) {
        return this.flatMap(function (a) { return ob.flatMap(function (b) { return oc.flatMap(function (c) { return od.flatMap(function (d) { return oe.flatMap(function (e) { return of.map(function (ff) { return f(a, b, c, d, e, ff); }); }); }); }); }); });
    };
    /** @override */
    TryImpl.prototype.chain = function (ob) {
        return new TryBuilder1(this, ob);
    };
    return TryImpl;
}());
var SuccessImpl = (function (_super) {
    __extends(SuccessImpl, _super);
    function SuccessImpl(value) {
        _super.call(this);
        this.value = value;
        this.isSuccess = true;
        this.isFailure = false;
    }
    SuccessImpl.prototype.get = function () {
        return this.value;
    };
    SuccessImpl.prototype.getError = function () {
        throw 'Success has not Error';
    };
    SuccessImpl.prototype.flatMap = function (f) {
        try {
            return f(this.value);
        }
        catch (e) {
            return Failure(e);
        }
    };
    SuccessImpl.prototype.map = function (f) {
        var _this = this;
        return Try(function () { return f(_this.value); });
    };
    SuccessImpl.prototype.filter = function (f) {
        try {
            return f(this.value) ? this : Failure(new Error('Predicate does not hold for ' + this.value));
        }
        catch (e) {
            return Failure(e);
        }
    };
    SuccessImpl.prototype.failed = function () {
        return Failure(new Error('Success.failed'));
    };
    SuccessImpl.prototype.recover = function (f) {
        return Success(this.value);
    };
    SuccessImpl.prototype.recoverWith = function (f) {
        return Success(this.value);
    };
    return SuccessImpl;
}(TryImpl));
var FailureImpl = (function (_super) {
    __extends(FailureImpl, _super);
    function FailureImpl(e) {
        _super.call(this);
        this.e = e;
        this.isSuccess = false;
        this.isFailure = true;
    }
    FailureImpl.prototype.get = function () {
        throw this.e;
    };
    FailureImpl.prototype.getError = function () {
        return this.e;
    };
    FailureImpl.prototype.flatMap = function (f) {
        return Failure(this.e);
    };
    FailureImpl.prototype.map = function (f) {
        return new FailureImpl(this.e);
    };
    FailureImpl.prototype.filter = function (f) {
        return this;
    };
    FailureImpl.prototype.failed = function () {
        return this;
    };
    FailureImpl.prototype.recover = function (f) {
        try {
            var op = f(this.e);
            return op.nonEmpty ? Success(op.get()) : Failure(this.e);
        }
        catch (e) {
            return Failure(e);
        }
    };
    FailureImpl.prototype.recoverWith = function (f) {
        try {
            var op = f(this.e);
            return op.nonEmpty ? op.get() : Failure(this.e);
        }
        catch (e) {
            return Failure(e);
        }
    };
    return FailureImpl;
}(TryImpl));
// Builders
var TryBuilder1 = (function () {
    function TryBuilder1(oa, ob) {
        this.oa = oa;
        this.ob = ob;
    }
    TryBuilder1.prototype.run = function (f) {
        return this.oa.apply1(this.ob, f);
    };
    TryBuilder1.prototype.chain = function (oc) {
        return new TryBuilder2(this.oa, this.ob, oc);
    };
    return TryBuilder1;
}());
exports.TryBuilder1 = TryBuilder1;
var TryBuilder2 = (function () {
    function TryBuilder2(oa, ob, oc) {
        this.oa = oa;
        this.ob = ob;
        this.oc = oc;
    }
    TryBuilder2.prototype.run = function (f) {
        return this.oa.apply2(this.ob, this.oc, f);
    };
    TryBuilder2.prototype.chain = function (od) {
        return new TryBuilder3(this.oa, this.ob, this.oc, od);
    };
    return TryBuilder2;
}());
exports.TryBuilder2 = TryBuilder2;
var TryBuilder3 = (function () {
    function TryBuilder3(oa, ob, oc, od) {
        this.oa = oa;
        this.ob = ob;
        this.oc = oc;
        this.od = od;
    }
    TryBuilder3.prototype.run = function (f) {
        return this.oa.apply3(this.ob, this.oc, this.od, f);
    };
    TryBuilder3.prototype.chain = function (oe) {
        return new TryBuilder4(this.oa, this.ob, this.oc, this.od, oe);
    };
    return TryBuilder3;
}());
exports.TryBuilder3 = TryBuilder3;
var TryBuilder4 = (function () {
    function TryBuilder4(oa, ob, oc, od, oe) {
        this.oa = oa;
        this.ob = ob;
        this.oc = oc;
        this.od = od;
        this.oe = oe;
    }
    TryBuilder4.prototype.run = function (f) {
        return this.oa.apply4(this.ob, this.oc, this.od, this.oe, f);
    };
    TryBuilder4.prototype.chain = function (of) {
        return new TryBuilder5(this.oa, this.ob, this.oc, this.od, this.oe, of);
    };
    return TryBuilder4;
}());
exports.TryBuilder4 = TryBuilder4;
var TryBuilder5 = (function () {
    function TryBuilder5(oa, ob, oc, od, oe, of) {
        this.oa = oa;
        this.ob = ob;
        this.oc = oc;
        this.od = od;
        this.oe = oe;
        this.of = of;
    }
    TryBuilder5.prototype.run = function (f) {
        return this.oa.apply5(this.ob, this.oc, this.od, this.oe, this.of, f);
    };
    return TryBuilder5;
}());
exports.TryBuilder5 = TryBuilder5;

==> scalts-0.6.0.tgz: package/src/Try.js <==
/* tslint:disable:no-use-before-declare */
"use strict";
const Optional_1 = require("./Optional");
const Either_1 = require("./Either");
function Try(f) {
    try {
        return Success(f());
    }
    catch (e) {
        return Failure(e);
    }
}
exports.Try = Try;
function Success(a) {
    return new SuccessImpl(a);
}
exports.Success = Success;
function Failure(e) {
    return new FailureImpl(e);
}
exports.Failure = Failure;
//------------------------------------
//
// Implementation section.
//
//------------------------------------
class TryImpl {
    toString() {
        return this.isSuccess ? `Success(${this.get()}})` : `Failure(${this.getError()}})`;
    }
    get() {
        throw 'impl child';
    }
    getError() {
        throw 'impl child';
    }
    flatMap(f) {
        throw 'impl child';
    }
    map(f) {
        throw 'impl child';
    }
    filter(f) {
        throw 'impl child';
    }
    toOptional() {
        return this.isSuccess ? Optional_1.Some(this.get()) : Optional_1.None;
    }
    toEither() {
        return this.isSuccess ? Either_1.Right(this.get()) : Either_1.Left(this.getError());
    }
    failed() {
        throw 'impl child';
    }
    recover(f) {
        throw 'impl child';
    }
    recoverWith(f) {
        throw 'impl child';
    }
    fold(fe, ff) {
        return this.isFailure ? fe(this.getError()) : ff(this.get());
    }
    getOrElse(a) {
        return this.isFailure ? a() : this.get();
    }
    orElse(a) {
        return this.isFailure ? a : this;
    }
    foreach(f) {
        if (this.isSuccess) {
            f(this.get());
        }
    }
    transform(fs, ff) {
        try {
            return this.isSuccess ? fs(this.get()) : ff(this.getError());
        }
        catch (e) {
            return Failure(e);
        }
    }
    /** @override */
    apply1(ob, f) {
        return this.flatMap(a => ob.map(b => f(a, b)));
    }
    /** @override */
    apply2(ob, oc, f) {
        return this.flatMap(a => ob.flatMap(b => oc.map(c => f(a, b, c))));
    }
    /** @override */
    apply3(ob, oc, od, f) {
        return this.flatMap(a => ob.flatMap(b => oc.flatMap(c => od.map(d => f(a, b, c, d)))));
    }
    /** @override */
    apply4(ob, oc, od, oe, f) {
        return this.flatMap(a => ob.flatMap(b => oc.flatMap(c => od.flatMap(d => oe.map(e => f(a, b, c, d, e))))));
    }
    /** @override */
    apply5(ob, oc, od, oe, of, f) {
        return this.flatMap(a => ob.flatMap(b => oc.flatMap(c => od.flatMap(d => oe.flatMap(e => of.map(ff => f(a, b, c, d, e, ff)))))));
    }
    /** @override */
    chain(ob) {
        return new TryBuilder1(this, ob);
    }
}
class SuccessImpl extends TryImpl {
    constructor(value) {
        super();
        this.value = value;
        this.isSuccess = true;
        this.isFailure = false;
    }
    get() {
        return this.value;
    }
    getError() {
        throw 'Success has not Error';
    }
    flatMap(f) {
        try {
            return f(this.value);
        }
        catch (e) {
            return Failure(e);
        }
    }
    map(f) {
        return Try(() => f(this.value));
    }
    filter(f) {
        try {
            return f(this.value) ? this : Failure(new Error('Predicate does not hold for ' + this.value));
        }
        catch (e) {
            return Failure(e);
        }
    }
    failed() {
        return Failure(new Error('Success.failed'));
    }
    recover(f) {
        return Success(this.value);
    }
    recoverWith(f) {
        return Success(this.value);
    }
}
class FailureImpl extends TryImpl {
    constructor(e) {
        super();
        this.e = e;
        this.isSuccess = false;
        this.isFailure = true;
    }
    get() {
        throw this.e;
    }
    getError() {
        return this.e;
    }
    flatMap(f) {
        return Failure(this.e);
    }
    map(f) {
        return new FailureImpl(this.e);
    }
    filter(f) {
        return this;
    }
    failed() {
        return this;
    }
    recover(f) {
        try {
            const op = f(this.e);
            return op.nonEmpty ? Success(op.get()) : Failure(this.e);
        }
        catch (e) {
            return Failure(e);
        }
    }
    recoverWith(f) {
        try {
            const op = f(this.e);
            return op.nonEmpty ? op.get() : Failure(this.e);
        }
        catch (e) {
            return Failure(e);
        }
    }
}
// Builders
class TryBuilder1 {
    constructor(oa, ob) {
        this.oa = oa;
        this.ob = ob;
    }
    run(f) {
        return this.oa.apply1(this.ob, f);
    }
    chain(oc) {
        return new TryBuilder2(this.oa, this.ob, oc);
    }
}
exports.TryBuilder1 = TryBuilder1;
class TryBuilder2 {
    constructor(oa, ob, oc) {
        this.oa = oa;
        this.ob = ob;
        this.oc = oc;
    }
    run(f) {
        return this.oa.apply2(this.ob, this.oc, f);
    }
    chain(od) {
        return new TryBuilder3(this.oa, this.ob, this.oc, od);
    }
}
exports.TryBuilder2 = TryBuilder2;
class TryBuilder3 {
    constructor(oa, ob, oc, od) {
        this.oa = oa;
        this.ob = ob;
        this.oc = oc;
        this.od = od;
    }
    run(f) {
        return this.oa.apply3(this.ob, this.oc, this.od, f);
    }
    chain(oe) {
        return new TryBuilder4(this.oa, this.ob, this.oc, this.od, oe);
    }
}
exports.TryBuilder3 = TryBuilder3;
class TryBuilder4 {
    constructor(oa, ob, oc, od, oe) {
        this.oa = oa;
        this.ob = ob;
        this.oc = oc;
        this.od = od;
        this.oe = oe;
    }
    run(f) {
        return this.oa.apply4(this.ob, this.oc, this.od, this.oe, f);
    }
    chain(of) {
        return new TryBuilder5(this.oa, this.ob, this.oc, this.od, this.oe, of);
    }
}
exports.TryBuilder4 = TryBuilder4;
class TryBuilder5 {
    constructor(oa, ob, oc, od, oe, of) {
        this.oa = oa;
        this.ob = ob;
        this.oc = oc;
        this.od = od;
        this.oe = oe;
        this.of = of;
    }
    run(f) {
        return this.oa.apply5(this.ob, this.oc, this.od, this.oe, this.of, f);
    }
}
exports.TryBuilder5 = TryBuilder5;
